@@ -72,18 +72,18 @@ class Manager(ABC):
                    |                     |      |                   |         └──────────────┘
                    |                     |      └───────────────────┘
                    |                     |
-                   |             ┌───────┴──────┬────────────────────┐
-                   ▼             ▼              ▼                    ▼
-             ┌───────────┐ ┌────────────┐ ┌─────────────┐ ┌─────────────────────┐
-             |  setup()  | | on_start() | | on_finish() | | convert_to_petition |
-             └───────────┘ └────────────┘ └─────────────┘ └─────────────────────┘
-
-                                                 is_client
-                                                 ────┬────
-                                                     |
-                                                     |            ┌─────────────┐
-                                                     ├───────────►|  connect()  |
-                                                     |            └─────────────┘
+                   |             ┌───────┴────────────────┬────────────────────┐
+                   ▼             ▼                        ▼                    ▼
+             ┌───────────┐ ┌──────────────────┐ ┌───────────────────┐ ┌─────────────────────┐
+             |  setup()  | | start_petition() | | finish_petition() | | convert_to_petition |
+             └───────────┘ └─┬────────────────┘ └─┬─────────────────┘ └─────────────────────┘
+                             |             ┌──────┘
+                             |             |     is_client
+                             |             |     ────┬────
+                             ▼             ▼         |
+                    ┌────────────┐  ┌─────────────┐  |            ┌─────────────┐
+                    | on_start() |  | on_finish() |  ├───────────►|  connect()  |
+                    └────────────┘  └─────────────┘  |            └─────────────┘
                                                      |           ┌───────────────┐
                                                      ├──────────►| send(message) |
                                                      |           └───────────────┘
@@ -193,6 +193,7 @@ class Manager(ABC):
         self._create_processor = create_processor
         self._is_client = is_client
         self._set_lock = multiprocessing.Lock()
+        self._petition_lock = multiprocessing.Lock()
         self._enqueued_messages = set()
         self._shutdown = multiprocessing.Value("b", False)
 
@@ -337,11 +338,11 @@ class Manager(ABC):
                 log.debug("finishing manager")
                 try:
                     self.manager.shutdown()
-                except AttributeError:
-                    # ignore AttributeError errors
+                    # wait at most 60 seconds before considering the manager done
+                    self.manager.join(timeout=60.0)  # pylint: disable=no-member
+                except (AttributeError, AssertionError):
+                    # ignore AttributeError and AssertionError errors
                     pass
-                # wait at most 60 seconds before considering the manager done
-                self.manager.join(timeout=60.0)  # pylint: disable=no-member
 
             log.debug("parent handler finished")
         except Exception as e:
@@ -542,8 +543,56 @@ class Manager(ABC):
         """
         ...
 
+    def start_petition(self, petition: Petition) -> bool:
+        """Method to be called when the processor accepts a petition to be enqueued. This
+        internal method **should not be overrideden** nor **called directly** by subclasses,
+        use :func:`on_start` instead for implementing your own behavior.
+
+        By defining this method, subclasses can implement their own behavior based on
+        their needs instead of orchestrator ones (i.e.: watchdog petitions). For
+        preserving the same behavior as the one in older versions, the :func:`on_start`
+        method is called in a mutually exclusive way among other processes.
+
+        On its own, this method keeps track of the enqueued petitions and nothing else.
+        See :class:`WatchdogManager` for seeing a different behavior of this method
+        for handling Orcha's internal petitions.
+
+        Important:
+            Since version ``0.2.6-1`` it is ensured that the :func:`on_start` method is
+            called iff the petition is :obj:`enqueued <orcha.interfaces.PetitionState.ENQUEUED>`
+            and not running yet, so there is no need to implement such logic at subclasses.
+
+        Args:
+            petition (:obj:`Petition <orcha.interfaces.Petition>`): petition that is about
+                to be started.
+
+        Returns:
+            :obj:`bool`: if the petition was started correctly.
+
+        .. versionchanged:: 0.2.6-2
+            :obj:`Petition's condition <orcha.interfaces.Petition.condition>` is now checked at
+            manager level. If the condition is falsy, then this function will return :obj:`False`
+            but will keep the received state, it is, usually
+            :obj:`ENQUEUED <orcha.interfaces.PetitionState.ENQUEUED>`. The
+            :class:`Processor <orcha.lib.Processor>` will check for both healthiness and state
+            for re-enqueuing the petition again when the condition was not satisfied.
+        """
+        with self._petition_lock:
+            if (
+                petition.condition(petition)
+                and not self._is_client
+                and petition.state.is_enqueued
+                and not self.is_running(petition)
+            ):
+                with self._set_lock:
+                    self._enqueued_messages.add(petition.id)
+                    petition.state = PetitionState.RUNNING
+
+                return self.on_start(petition)
+        return False
+
     @abstractmethod
-    def on_start(self, petition: Petition):
+    def on_start(self, petition: Petition) -> bool:
         """Action to be run when a :class:`Petition <orcha.interfaces.Petition>` has started
         its execution, in order to manage how the manager will react to other petitions when
         enqueued (i.e.: to have a control on the execution, how many items are running, etc.).
@@ -553,36 +602,69 @@ class Manager(ABC):
 
         Note:
             This method is intended to be used for managing requests queues and how are
-            they handled depending on, for example, CPU usage. For a custom behavior
-            on execution, please better use :attr:`action <orcha.interfaces.Petition.action>`.
+            they handled depending on, for example, CPU usage or starting services.
+            For a custom behavior on execution, please better use
+            :attr:`action <orcha.interfaces.Petition.action>`.
 
         Warning:
-            It is **fundamental** that child server managers call ``super()`` on this
-            method, as not doing this will break the non-duplicates algorithm::
-
-                from orcha.lib import Manager
-
-                class ServerManager(Manager):
-                    ...
-
-                    def on_start(self, *args):
-                        super().on_start(*args)
-
-            In addition, this method is run by the :class:`Processor <orcha.lib.Processor>` in
+            This method is called by :func:`start_petition` in
             a mutex environment, so it is **required** that no unhandled exception happens here
             and that the operations done are minimal, as other processes will have to wait until
             this call is done.
 
+        Important:
+            Since version ``0.2.5`` this function shall return a boolean value indicating
+            if the :attr:`petition status <orcha.interfaces.Petition.status>` is healthy
+            or not. If this function raises an exception, automatically the
+            :attr:`petition state <orcha.interfaces.Petition.state>` will be set to
+            :attr:`PetitionState.BROKEN <orcha.interfaces.PetitionState.BROKEN>`.
+
+            When an :func:`on_start` method fails (``healthy = False``), the
+            :attr:`action <orcha.interfaces.Petition.action>` call is skipped and directly
+            :func:`on_finish` is called, in which you may handle that
+            :attr:`BROKEN <orcha.interfaces.PetitionState.BROKEN>` status
+
         Args:
-            petition (Petition): the petition that has just started
+            petition (:obj:`Petition <orcha.interfaces.Petition>`): the petition that has
+                just started
+
+        Returns:
+            :obj:`bool`: :obj:`True` if the start process went fine, :obj:`False` otherwise.
+
+        .. versionadded:: 0.2.6
+            Child classes do not require to call ``super`` for this method call.
+        """
+        ...
+
+    def finish_petition(self, petition: Petition):
+        """Method that is called when a petition has finished its execution, if for example it
+        has been finished abruptly or if it has finished OK. If a petition reaches this function,
+        its state should be either :attr:`PetitionState.FINISHED` or :attr:`PetitionState.BROKEN`.
+
+        If the petition is valid, then :func:`on_finish` will be called. This
+        internal method **should not be overrideden** nor **called directly** by subclasses,
+        use :func:`on_finish` instead for implementing your own behavior.
+
+        On its own, this method keeps track of the enqueued petitions and nothing else.
+        See :class:`WatchdogManager` for seeing a different behavior of this method
+        for handling Orcha's internal petitions.
+
+        Args:
+            petition (:obj:`Petition <orcha.interfaces.Petition>`): petition that is about
+                to be started.
         """
         if not self._is_client:
-            with self._set_lock:
-                self._enqueued_messages.add(petition.id)
-                petition.state = PetitionState.RUNNING
+            if self.is_running(petition):
+                with self._set_lock:
+                    self._enqueued_messages.remove(petition.id)
+                    if not petition.state.is_in_broken_state:
+                        petition.state = PetitionState.FINISHED
+
+                with self._petition_lock:
+                    self.on_finish(petition)
 
     @abstractmethod
-    def on_finish(self, petition: Petition) -> bool:
+    def on_finish(self, petition: Petition):
         """Action to be run when a :class:`Petition <orcha.interfaces.Petition>` has started
         its execution, in order to manage how the manager will react to other petitions when
         enqueued (i.e.: to have a control on the execution, how many items are running, etc.).
@@ -597,52 +679,24 @@ class Manager(ABC):
             :attr:`action <orcha.interfaces.Petition.action>`.
 
         Warning:
-            It is **fundamental** that child server managers call ``super()`` on this
-            method, as not doing this will break the non-duplicates algorithm::
-
-                from orcha.lib import Manager
-
-                class ServerManager(Manager):
-                    ...
-
-                    def on_finish(self, *args) -> bool:
-                        existed = super().on_finish(*args)
-                        if existed:
-                            # do your stuff
-                            ...
-                        return existed
-
-            Notice that the :func:`on_finish` returns a boolean value indicating whether
-            if the request for the :class:`petition <orcha.interfaces.Petition>` was successful
-            or not. A request is considered unsuccessful if one of the following conditions is met:
-
-                + The current manager **is a client**.
-                + The :class:`petition <orcha.interfaces.Petition>` was not registered (it is not
-                  a running petition).
-
-            In addition, this method is run by the :class:`Processor <orcha.lib.Processor>` in
+            This method is called by :func:`finish_petition` in
             a mutex environment, so it is **required** that no unhandled exception happens here
             and that the operations done are minimal, as other processes will have to wait until
             this call is done.
 
+        Important:
+            Since version ``0.2.6`` there is no need to return any value. It is ensured that this
+            method is called iff the received petition existed and was running.
+
         Args:
-            petition (Petition): the petition that has just started
+            petition (:obj:`Petition <orcha.interfaces.Petition>`): the petition that has
+                just started
 
-        Returns:
-            bool: :obj:`True` if the finish request was successful, :obj:`False` otherwise.
-
-                  A finish request is considered successful if the petition was registered
-                  and running. See the warning above to know which one is returned in each
-                  situation.
+        .. versionadded:: 0.2.6
+            This method returns nothing as it is ensured to be called only iff the given petition
+            was running.
         """
-        if not self._is_client:
-            if self.is_running(petition):
-                with self._set_lock:
-                    self._enqueued_messages.remove(petition.id)
-                    petition.state = PetitionState.FINISHED
-                return True
-            return False
-        return False
+        ...
 
 
 class ClientManager(Manager):
@@ -822,6 +876,25 @@ class WatchdogManager(Manager):
 
         return None
 
+    def start_petition(self, petition: Petition) -> bool:
+        if not isinstance(petition, WatchdogPetition):
+            return super().start_petition(petition)
+
+        petition.state = PetitionState.RUNNING
+        return True
+
+    def finish_petition(self, petition: Petition):
+        if not isinstance(petition, WatchdogPetition):
+            super().finish_petition(petition)
+        else:
+            if petition.state.is_in_broken_state:
+                log.critical(
+                    "Watchdog request did not succeed in time! Failed after %s",
+                    petition.elapsed_time,
+                )
+            else:
+                petition.state = PetitionState.FINISHED
+
 
 class WatchdogClientManager(ClientManager, WatchdogManager):
     """
