@@ -81,15 +81,15 @@ class Processor:
          | ╔══════════════════════════╗ ║       ╔══════════════════╩═════╗
          ├►║ Internal petition thread ╠═║══════►║ Petition launch thread ║
          | ╚══════════════════════════╝ ▼       ╚══════════════════╤═════╝
-         |       ╔════════════════════════╗                 ▲      |  ┌─────────────────────┐
-         └──────►║ Internal signal thread ╠═════════════════╝      ├─►| manager.on_start(p) |
-                 ╚════════════════════════╝   send SIGTERM         |  └─────────────────────┘
+         |       ╔════════════════════════╗                 ▲      |  ┌───────────────────────────┐
+         └──────►║ Internal signal thread ╠═════════════════╝      ├─►| manager.start_petition(p) |
+                 ╚════════════════════════╝   send SIGTERM         |  └───────────────────────────┘
                                                                    |   ┌─────────────────┐
                                                                    ├──►| p.action(fn, p) |
                                                                    |   └─────────────────┘
-                                                                   | ┌──────────────────────┐
-                                                                   └►| manager.on_finish(p) |
-                                                                     └──────────────────────┘
+                                                                   | ┌────────────────────────────┐
+                                                                   └►| manager.finish_petition(p) |
+                                                                     └────────────────────────────┘
 
     Note:
         Ideally, you don't need to create any instance for this class, as it is completely
@@ -424,11 +424,17 @@ class Processor:
                 self._gc_event.set()
                 return
 
-            log.debug('petition "%s" satisfied condition', p)
-            self.manager.on_start(p)
+        log.debug('petition "%s" satisfied condition', p)
+        try:
+            healthy = self.manager.start_petition(p)
+        except Exception as e:
+            p.state = PetitionState.BROKEN
+            log.critical("Unable to start petition %s with error: %s", p, e)
+            healthy = False
 
         try:
-            p.action(assign_pid, p)
+            if healthy:
+                p.action(assign_pid, p)
         except Exception as e:
             log.warning(
                 'unhandled exception while running petition "%s" -> "%s"', p, e, exc_info=True
@@ -437,9 +443,9 @@ class Processor:
             log.debug('petition "%s" finished, triggering callbacks', p)
             self._petitions.pop(p.id, None)
 
-            with self._pred_lock:
-                self.manager.on_finish(p)
+            self.manager.finish_petition(p)
 
+            # set garbage collector flag to cleanup ourselves
             self._gc_event.set()
 
     def _signal_handler(self):
